/**
 * main.c
 */

#include <string.h>
#include "DSP28x_Project.h"     // Device Headerfile and Examples Include File
#include "F28M35x_CpuTimers.h"
#include "./device/device.h"
#include "./include/nitee/Equipment.h"

extern Uint16 RamfuncsLoadStart;
extern Uint16 RamfuncsLoadSize;
extern Uint16 RamfuncsRunStart;

Uint16 indication_led_count;

void Equipment_init();
interrupt void adc1_isr(void);

Equipment *equip;

int main(void)
{
	// Init C28 core
	InitSysCtrl();

	// Copy time critical code and Flash setup code to RAM
	// This includes the following functions: InitFlash();
	// The  RamfuncsLoadStart, RamfuncsLoadSize and RamfuncsRunStart
	// symbols are created by the linker. Refer to the device .cmd file.
	// memcpy(&RamfuncsRunStart, &RamfuncsLoadStart, (size_t)&RamfuncsLoadSize);
	InitFlash();
	InitPieCtrl();
	InitPieVectTable();

	// Allows writing to protected registers
	EALLOW;

	// Defining an address for the ISR to be called
	PieVectTable.ADCINT1 = &adc1_isr;

	EINT;  // Enable Global interrupt INTM
	ERTM;  // Enable Global realtime interrupt DBGM

	// Init peripherals
	DeviceInit();

	// Revokes permition to write protected registers
	EDIS;

	// Init Equipment data structure
	// equip = Equipment_init();

	while(1);

	return 0;
}

interrupt void adc1_isr(void)
{

	PROFILE_LED = 1;

	if(indication_led_count++ > 6250)
	{
		INDICATION_LED ^= 1;
		indication_led_count = 0;
	}

	PROFILE_LED = 0;

	Adc1Regs.ADCINTFLGCLR.bit.ADCINT1 = 1;
	PieCtrlRegs.PIEACK.all = PIEACK_GROUP1;
}
